==> jc-1.4.0.tar.gz: javax/swing/text/StyleConstants__24ColorConstants.h <==
// public class javax.swing.text.StyleConstants$ColorConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33098ca6f888e073 javax_swing_text_StyleConstants
// @dep_class a9e4686447be9bf6 javax_swing_text_StyleConstants__24ColorConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24ColorConstants_H_
#define _JC_javax_swing_text_StyleConstants__24ColorConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$refs	_jc_javax_swing_text_StyleConstants__24ColorConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object	_jc_javax_swing_text_StyleConstants__24ColorConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods	_jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtable	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Background;
	struct _jc_java_lang_Object$object	*Foreground;
};
extern _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct _jc_javax_swing_text_StyleConstants__24ColorConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24ColorConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24ColorConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods	javax_swing_text_StyleConstants__24ColorConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$refs {
    _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs	javax_swing_text_StyleConstants__24ColorConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs	javax_swing_text_StyleConstants__24ColorConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object {
	_jc_javax_swing_text_StyleConstants__24ColorConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype _jc_javax_swing_text_StyleConstants__24ColorConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24ColorConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24ColorConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24ColorConstants_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyleConstants__24ColorConstants.h <==
// public class javax.swing.text.StyleConstants$ColorConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 602dc460083efcf4 javax_swing_text_StyleConstants
// @dep_class e46a648ec940de68 javax_swing_text_StyleConstants__24ColorConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24ColorConstants_H_
#define _JC_javax_swing_text_StyleConstants__24ColorConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$refs	_jc_javax_swing_text_StyleConstants__24ColorConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object	_jc_javax_swing_text_StyleConstants__24ColorConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods	_jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtable	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Background;
	struct _jc_java_lang_Object$object	*Foreground;
};
extern _jc_javax_swing_text_StyleConstants__24ColorConstants$fields_struct _jc_javax_swing_text_StyleConstants__24ColorConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24ColorConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24ColorConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vmethods	javax_swing_text_StyleConstants__24ColorConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$refs {
    _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_refs	javax_swing_text_StyleConstants__24ColorConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24ColorConstants$sub_nonrefs	javax_swing_text_StyleConstants__24ColorConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24ColorConstants$object {
	_jc_javax_swing_text_StyleConstants__24ColorConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24ColorConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24ColorConstants$vtype _jc_javax_swing_text_StyleConstants__24ColorConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24ColorConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24ColorConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24ColorConstants_H_ */
